blackfynn-py
============

Python client and command line tool for Blackfynn.

Installation
------------

To install, simply

.. code:: bash

    pip install -U blackfynn

See `install notes <INSTALL.rst>`_ for more details.

Documentation
-------------

Client and command line documentation can be found on `Blackfynn’s
documentation website`_.

.. _Blackfynn’s documentation website: http://docs.blackfynn.io/client_tools/clients/python_index.html
